@@ -266,6 +266,30 @@ static void devices_reload_test(void) {
 	linphone_core_manager_destroy(mgr);
 }
 
+static void codec_usability_test(void) {
+	LinphoneCoreManager *mgr = linphone_core_manager_new2("empty_rc", FALSE);
+	PayloadType *pt = linphone_core_find_payload_type(mgr->lc, "PCMU", 8000, -1);
+	
+	BC_ASSERT_TRUE(pt!=NULL);
+	if (!pt) goto end;
+	/*no limit*/
+	linphone_core_set_upload_bandwidth(mgr->lc, 0);
+	linphone_core_set_download_bandwidth(mgr->lc, 0);
+	BC_ASSERT_TRUE(linphone_core_check_payload_type_usability(mgr->lc, pt));
+	/*low limit*/
+	linphone_core_set_upload_bandwidth(mgr->lc, 50);
+	linphone_core_set_download_bandwidth(mgr->lc, 50);
+	BC_ASSERT_FALSE(linphone_core_check_payload_type_usability(mgr->lc, pt));
+	
+	/*reasonable limit*/
+	linphone_core_set_upload_bandwidth(mgr->lc, 200);
+	linphone_core_set_download_bandwidth(mgr->lc, 200);
+	BC_ASSERT_TRUE(linphone_core_check_payload_type_usability(mgr->lc, pt));
+	
+end:
+	linphone_core_manager_destroy(mgr);
+}
+
 test_t setup_tests[] = {
 	{ "Version check", linphone_version_test },
 	{ "Linphone Address", linphone_address_test },
@@ -279,7 +303,8 @@ test_t setup_tests[] = {
 	{ "LPConfig zero_len value from file", linphone_lpconfig_from_file_zerolen_value },
 	{ "LPConfig zero_len value from XML", linphone_lpconfig_from_xml_zerolen_value },
 	{ "Chat room", chat_root_test },
-	{ "Devices reload", devices_reload_test }
+	{ "Devices reload", devices_reload_test },
+	{ "Codec usability", codec_usability_test }
 };
 
 test_suite_t setup_test_suite = {
